@@ -53,12 +53,6 @@ def test_cholesky_const(const_pd):
 def test_cholesky_lr(lr_pd):
     chol = B.dense(B.cholesky(lr_pd))
     allclose(B.matmul(chol, chol, tr_b=True), lr_pd)
-
-    with AssertDenseWarning("cannot ensure positivity of <low-rank>"):
-        lr_pd2 = LowRank(lr_pd.left, 1 * lr_pd.right, lr_pd.middle)
-        chol = B.dense(B.cholesky(lr_pd2))
-        allclose(B.matmul(chol, chol, tr_b=True), lr_pd)
-
     _check_cache(lr_pd)
 
 
