@@ -11,8 +11,7 @@ def test_woodbury_formatting():
         repr(Woodbury(diag, lr)) == "<Woodbury matrix: shape=3x3, dtype=float64\n"
         " diag=<diagonal matrix: shape=3x3, dtype=float64\n"
         "       diag=[1. 1. 1.]>\n"
-        " lr=<low-rank matrix: shape=3x3, dtype=float64, rank=1,"
-        " sign=0\n"
+        " lr=<low-rank matrix: shape=3x3, dtype=float64, rank=1\n"
         "     left=[[1.]\n"
         "           [1.]\n"
         "           [1.]]\n"
